@@ -5,7 +5,7 @@ import os
 import subprocess
 import time
 from datetime import datetime
-from shutil import which
+from shutil import which, copyfile
 from subprocess import Popen
 
 from web3 import Web3, HTTPProvider
@@ -159,7 +159,6 @@ class Node:
         :type enode: string
         :param localhost: whether the node is running on localhost or not
         :type localhost: bool
-        TODO: Add support for not localhost
         :return: success indicator
         :rtype: bool
         """
@@ -179,6 +178,9 @@ class Node:
         else:
             return False
 
+    def add_foreign_account(self, key):
+        copyfile(key, "{}/keystore".format(self.datadir))
+
     def get_first_account(self):
         """
         Get the first account that gets created as part of the create node function.
